@@ -5,7 +5,7 @@ use warnings;
 use Moose;
 
 # ABSTRACT: Insert example into your POD from a file
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -13,6 +13,8 @@ with 'Dist::Zilla::Role::FileFinderUser' => {
   default_finders => [ qw( :InstallModules :ExecFiles ) ],
 };
 
+has remove_boiler => (is => 'ro', isa => 'Int');
+
 sub munge_files
 {
   my($self) = @_;
@@ -39,7 +41,24 @@ sub _slurp_example
   {
     $self->log_fatal("no such example file $filename");
   }
-  join "\n", map { " $_" } split /\n\r?/, $file->slurp;
+  if($self->remove_boiler)
+  {
+    my $fh = $file->openr;
+    my $buffer;
+    while(<$fh>)
+    {
+      next if /^\s*$/;
+      next if /^#!\/usr\/bin\/perl/;
+      next if /^use strict;$/;
+      next if /^use warnings;$/;
+      return '' if eof $fh;
+      return join "\n", map { " $_" } split /\n\r?/, $_ . do { local $/; <$fh> };
+    }
+  }
+  else
+  {
+    return join "\n", map { " $_" } split /\n\r?/, $file->slurp;
+  }
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -58,7 +77,7 @@ Dist::Zilla::Plugin::InsertExample - Insert example into your POD from a file
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -104,6 +123,13 @@ When the example is inserted into your pod a space will be appended
 at the start of each line so that it is printed in a fixed width
 font.
 
+=head1 OPTIONS
+
+=head2 remove_boiler
+
+Remove the "#!/usr/bin/perl", "use strict;" or "use warnings;" from
+the beginning of your example before inserting them into the POD.
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
